
***********************************************
*1. Loading Dataset
***********************************************

clear
*cd "USERfilepath," for example:
cd  "/Users/weghorkr/Dropbox/List Experiment Paper/Replication/"
use kramon_weghorst_poq2019.dta


***********************************************
*2. Figure 5.
***********************************************

***********************

histogram list_difference_activity, ///
percent title(Activity List) ytitle(Percent of Respondents)   ytitle(, size(medsmall)) ///
ylabel(0(20)60) xtitle(, size(zero)) ///
xlabel(-4(1)5)  addlabopts(yvarformat(%2.1f)) ///
saving(activity.gph, replace)
histogram list_difference_food, ///
percent title(Food List)  ytitle(, size(small)) ylabel(0(20)60) ///
 xtitle(, size(zero)) xlabel(-4(1)5)  addlabopts(yvarformat(%2.1f))  ///
saving(food.gph, replace)
graph combine activity.gph food.gph, ///
rows(1) ycommon  saving(listfail, replace) b1title("[List Response - Total Individual Items]",size(medium))

graph export "listfail.pdf", replace
***********************************************
*3. Figure 6
***********************************************
**We produced this figure by manually combining  information generated from several statistical analyses /// 
The analyses are found under Appendix B.6 of this replicaiton file.  



***********************************************
*4. Table 5
***********************************************
*Note: summary statistics and tabulations appearing in text are presented below ///
They are organized by panel and within each panel moving left to right

tab SC1
sum SC1
tab ST1
sum ST1
tab SC2
sum SC2
tab ST2
sum ST2


tab TC1
sum TC1
tab TT1
sum TT1
tab TC2
sum TC2
tab TT2
sum TT2


tab CC1
sum CC1
tab CT1
sum CT1
tab CC2
sum CC2
tab CT2
sum CT2

***********************************************
*5. Table 6
***********************************************
***************
*Overall (All Respondents)
***************
tab violence_wneutral 
ttest SC1 == ST1 , unpaired unequal welch
ttest SC2 == ST2, unpaired unequal welch

***************
*Disaggregated by Education Level
***************
tab violence if education==1
ttest SC1 == ST1 if education==1, unpaired unequal welch
ttest SC2 == ST2 if education==1, unpaired unequal welch
tab violence if education==2
ttest SC1 == ST1 if education==2, unpaired unequal welch
ttest SC2 == ST2 if education==2, unpaired unequal welch
tab violence if education==3
ttest SC1 == ST1 if education==3, unpaired unequal welch
ttest SC2 == ST2 if education==3, unpaired unequal welch
tab violence if education==4
ttest SC1 == ST1 if education==4, unpaired unequal welch
ttest SC2 == ST2 if education==5, unpaired unequal welch
tab violence if education==5
ttest SC1 == ST1 if education==5, unpaired unequal welch
ttest SC2 == ST2 if education==5, unpaired unequal welch

***************
*Disaggregated by Numeracy
***************
tab violence if total_activity_additional<5 & education!=.
ttest SC1 == ST1 if total_activity_additional<5, unpaired unequal welch
ttest SC2 == ST2 if total_activity_additional<5, unpaired unequal welch


tab violence if total_activity_additional>4 & education!=.
ttest SC1 == ST1 if total_activity_additional>4, unpaired unequal welch
ttest SC2 == ST2 if total_activity_additional>4, unpaired unequal welch



***************
*Disaggregated by Experiencing Income Shocks
***************
tab violence if cash_income==3
ttest SC1 == ST1 if cash_income==3, unpaired unequal welch
ttest SC2 == ST2 if cash_income==3, unpaired unequal welch
tab violence if cash_income==2
ttest SC1 == ST1 if cash_income==2, unpaired unequal welch
ttest SC2 == ST2 if cash_income==2, unpaired unequal welch
tab violence if cash_income==1
ttest SC1 == ST1 if cash_income==1, unpaired unequal welch
ttest SC2 == ST2 if cash_income==1, unpaired unequal welch



***************
*Disaggregated by Ethnicity
***************
tab violence if eth==0
ttest SC1 == ST1 if eth==0, unpaired unequal welch
ttest SC2 == ST2 if eth==0, unpaired unequal welch
tab violence if eth==1
ttest SC1 == ST1 if eth==1, unpaired unequal welch
ttest SC2 == ST2 if eth==1, unpaired unequal welch
tab violence if eth==2
ttest SC1 == ST1 if eth==2, unpaired 





***********************************************
*6. Appendix
***********************************************
*Note: Command order corresponds with table ordering
***********************************************
*Appendix A.1
***********************************************
tab female
tab age
tab education
tab cash_income

***********************************************
*Appendix A.2
***********************************************
tab female
tab order_tablet
tab suborder
tab tplacement

***********************************************
*Appendix A.3
***********************************************
tab female
tab order_tablet female, row
tab order_tablet age, row
tab order_tablet education, row
tab order_tablet cash_income




***********************************************
*Appendix B.6
***********************************************
*These analyses are organized to follow with Figure 6, moving left to right. 

logit food_fail i.violence_wneutral 
margins i.violence_wneutral, level(90)

logit food_fail  total_activity_additional
margins, at( total_activity_additional=(0 9))
logit food_fail education
margins, at(education=(1 5)) level(90)
logit act_fail i.violence_wneutral 
margins i.violence_wneutral, level(90)
logit act_fail education
margins, at(education=(1 5)) level(90)
logit no_match i.violence_wneutral 
margins i.violence_wneutral, level(90)
logit no_match education
margins, at(education=(1 5)) level(90)
***********************************************
*Appendix F.1
***********************************************
hist SC1 , percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Control 1") name(a, replace)
	
hist ST1 , percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Treatment 1") name(b, replace)

hist SC2 , percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Control 2") name(c, replace)
	
hist ST2 , percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Treatment 2") name(d, replace)

graph combine a b c d, col(2)


***********************************************
*Appendix F.2
***********************************************
hist TC1 , percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Control 1") name(a, replace)
	
hist TT1 , percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Treatment 1") name(b, replace)

hist TC2 , percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Control 2") name(c, replace)
	
hist TT2 , percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Treatment 2") name(d, replace)

graph combine a b c d, col(2)




***********************************************
*Appendix F.3
***********************************************
hist CC1 , percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Control 1") name(a, replace)
	
hist CT1 , percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Treatment 1") name(b, replace)

hist CC2 , percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Control 2") name(c, replace)
	
hist CT2 , percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Treatment 2") name(d, replace)

graph combine a b c d, col(2)









***********************************************
*Appendix F.4
***********************************************
hist SC1 if act_fail==1& food_fail==1, percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Control 1") name(a, replace)
	
hist ST1 if act_fail==1& food_fail==1, percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Treatment 1") name(b, replace)

hist SC2 if act_fail==1& food_fail==1, percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Control 2") name(c, replace)
	
hist ST2 if act_fail==1& food_fail==1, percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Treatment 2") name(d, replace)

graph combine a b c d, col(2)



***********************************************
*Appendix F.5
***********************************************
hist TC1 if act_fail==1& food_fail==1, percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Control 1") name(a, replace)
	
hist TT1 if act_fail==1& food_fail==1, percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Treatment 1") name(b, replace)

hist TC2 if act_fail==1& food_fail==1, percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Control 2") name(c, replace)
	
hist TT2 if act_fail==1& food_fail==1, percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Treatment 2") name(d, replace)

graph combine a b c d, col(2)




***********************************************
*Appendix F.6
***********************************************
hist CC1 if act_fail==1& food_fail==1, percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Control 1") name(a, replace)
	
hist CT1 if act_fail==1& food_fail==1, percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Treatment 1") name(b, replace)

hist CC2 if act_fail==1& food_fail==1, percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Control 2") name(c, replace)
	
hist CT2 if act_fail==1& food_fail==1, percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Treatment 2") name(d, replace)

graph combine a b c d, col(2)



***********************************************
*Appendix F.7
***********************************************
hist SC1 if education < 3, percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Control 1") name(a, replace)
	
hist ST1 if education < 3, percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Treatment 1") name(b, replace)

hist SC2 if education < 3, percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Control 2") name(c, replace)
	
hist ST2 if education < 3, percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Treatment 2") name(d, replace)

graph combine a b c d, col(2)
 


***********************************************
*Appendix F.8
***********************************************
hist TC1 if education < 3, percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Control 1") name(a, replace)
	
hist TT1 if education < 3, percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Treatment 1") name(b, replace)

hist TC2 if education < 3, percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Control 2") name(c, replace)
	
hist TT2 if education < 3, percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Treatment 2") name(d, replace)

graph combine a b c d, col(2)




***********************************************
*Appendix F.9
***********************************************
hist CC1 if education < 3, percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Control 1") name(a, replace)
	
hist CT1 if education < 3, percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Treatment 1") name(b, replace)

hist CC2 if education < 3, percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Control 2") name(c, replace)
	
hist CT2 if education < 3, percent discrete width(.5) xscale(range(0 5))  xlabel(#6) ///
	ylabel(, angle(horizontal)) ytitle("Percent") graphr(color(white)) color("gray") ///
	xtitle("LE Response") title("Treatment 2") name(d, replace)

graph combine a b c d, col(2)

